==> unit-1.1.17-sources.jar: io/intino/goros/unit/box/ui/displays/items/TrashTableOperationsItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class TrashTableOperationsItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Node, UnitBox> {
	public _45_4_1463868169 _45_4_1463868169;
	public TrashTableOperationsItem._45_4_1463868169. Restore restore;

    public TrashTableOperationsItem(UnitBox box) {
        super(box);
        id("a_1980355300");
    }

    @Override
	public void init() {
		super.init();
		if (_45_4_1463868169 == null) _45_4_1463868169 = register(new _45_4_1463868169(box()).<_45_4_1463868169>id("a_1230138361").owner(TrashTableOperationsItem.this));
		if (_45_4_1463868169 != null) restore = _45_4_1463868169.restore;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_45_4_1463868169 != null) _45_4_1463868169.unregister();
	}

	public class _45_4_1463868169 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public TrashTableOperationsItem._45_4_1463868169. Restore restore;

		public _45_4_1463868169(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (restore == null) restore = register(new Restore(box()).<Restore>id("a2091042572").owner(TrashTableOperationsItem.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (restore != null) restore.unregister();
		}

		public class Restore extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, UnitBox>  {

			public Restore(UnitBox box) {
				super(box);
				_title("Restore");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconButton"));
				_icon("RestoreFromTrash");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}

==> unit-2.1.5-sources.jar: io/intino/goros/unit/box/ui/displays/items/TrashTableOperationsItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class TrashTableOperationsItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Node, UnitBox> {
	public _45_4_01055490174 _45_4_01055490174;
	public TrashTableOperationsItem._45_4_01055490174. Restore restore;

	public TrashTableOperationsItem(UnitBox box) {
		super(box);
		id("a_1980355300");
	}

	@Override
	public void init() {
		super.init();
		if (_45_4_01055490174 == null) _45_4_01055490174 = register(new _45_4_01055490174(box()).<_45_4_01055490174>id("a1633473477").owner(TrashTableOperationsItem.this));
		if (_45_4_01055490174 != null) restore = _45_4_01055490174.restore;
	}

	@Override
	public void remove() {
		super.remove();
		if (_45_4_01055490174 != null) _45_4_01055490174.unregister();
	}

	public class _45_4_01055490174 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public TrashTableOperationsItem._45_4_01055490174. Restore restore;

		public _45_4_01055490174(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (restore == null) restore = register(new Restore(box()).<Restore>id("a2091042572").owner(TrashTableOperationsItem.this));
		}

		@Override
		public void unregister() {
			super.unregister();
			if (restore != null) restore.unregister();
		}

		public class Restore extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, UnitBox>  {

			public Restore(UnitBox box) {
				super(box);
				_title("Restore");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("MaterialIconButton"));
				_icon("RestoreFromTrash");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
				super.unregister();
			}
		}
	}
}
